Stan Math Library: stan/math/prim/scal/fun/lub_free.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
lub_free.hpp File Reference
`#include <stan/math/prim/scal/err/check_bounded.hpp>`
`#include <stan/math/prim/scal/fun/logit.hpp>`
`#include <stan/math/prim/scal/fun/lb_free.hpp>`
`#include <stan/math/prim/scal/fun/ub_free.hpp>`
`#include <limits>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , typename TL , typename TU >
boost::math::tools::promote_args< T, TL, TU >::type | stan::math::lub_free (const T y, TL lb, TU ub)
| Return the unconstrained scalar that transforms to the specified lower- and upper-bounded scalar given the specified bounds. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.